<?php

namespace Drupal\content_planner\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Link;
use Symfony\Component\HttpFoundation\RedirectResponse;

class DashboardDeleteForm extends ConfirmFormBase
{

  protected $dashboardId;

  public function getFormId()
  {
    return 'content_planner_dashboard_delete_form';
  }

  public function getQuestion()
  {
    return $this->t('Are you sure you want to delete the dashboard %dashboard?', ['%dashboard' => $this->dashboardId]);
  }

  public function getCancelUrl()
  {
    return new Url('content_planner.dashboard', ['dashboard_id' => $this->dashboardId]);
  }

  public function getDescription()
  {
    return $this->t('This action cannot be undone.');
  }

  public function buildForm(array $form, FormStateInterface $form_state, $dashboard_id = NULL)
  {
    $this->dashboardId = $dashboard_id;

    // Prevent deletion of the master dashboard.
    if ($this->dashboardId === 'master') {
      $this->messenger()->addError($this->t('The master dashboard cannot be deleted.'));

      $url = Url::fromRoute('content_planner.dashboard_tabs_settings');
        $link = Link::fromTextAndUrl($this->t('Go back to dashboard tabs administration'), $url)->toString();

        // Add the link to the form.
        $form['back_link'] = [
            '#type' => 'markup',
            '#markup' => $link,
            '#prefix' => '<p>',
            '#suffix' => '</p>',
        ];


      return $form;
    }

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state)
  {
    // Load the current tab configuration.
    $config_factory = \Drupal::service('config.factory');
    $dashboard_tabs_config = $config_factory->getEditable('content_planner.dashboard_tabs_settings');
    $tabs = $dashboard_tabs_config->get('dashboards') ?: [];

    // Remove the dashboard from the tabs configuration.
    foreach ($tabs as $key => $tab) {
      if ($tab['dashboard_id'] === $this->dashboardId) {
        unset($tabs[$key]);
        break; // Stop the loop once the dashboard is found and removed.
      }
    }

    // Re-index the array to clean up the keys after unset.
    $tabs = array_values($tabs);

    // Save the updated configuration.
    $dashboard_tabs_config->set('dashboards', $tabs)->save();

    // Perform the deletion of the dashboard configuration.
    \Drupal::service('content_planner.dashboard_settings_service')->deleteDashboardConfigurations($this->dashboardId);

    // Set a message and redirect to the main dashboard page.
    $this->messenger()->addMessage($this->t('Dashboard %dashboard has been deleted.', ['%dashboard' => $this->dashboardId]));
    $form_state->setRedirect('content_planner.dashboard');
  }

}
