<?php

namespace Drupal\content_planner\Plugin\DashboardBlock;

use Drupal\content_planner\DashboardBlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Provides a Dashboard block for Content Planner Dashboard.
 *
 * @DashboardBlock(
 *   id = "drupal_blog_rss_reader_block",
 *   name = @Translation("Drupal Announcements Widget"),
 *   category = "General",
 *   id_category = "general"
 * )
 */
class RSSReaderBlock extends DashboardBlockBase implements ContainerFactoryPluginInterface {

  use StringTranslationTrait;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The Kanban Statistic service.
   *
   * @var \Drupal\content_kanban\KanbanStatisticService
   */
  protected $kanbanStatisticService;

  /**
   * RSS Feed URL.
   */
  protected $rssUrl = 'https://www.drupal.org/section-blog/2603760/feed';

  /**
   * Number of items to show.
   */
  protected $numItemsToShow = 5;

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    // Load the RSS feed.
    if ($rss = simplexml_load_file($this->rssUrl)) {
      // Get the 'item' elements.
      $items = $rss->channel->item;

      // Keep track of how many items we've displayed.
      $count = 0;

      foreach ($items as $item) {
        if ($count >= $this->numItemsToShow) {
          break;
        }

         // Format the date. Note that your RSS feed might use a different tag for the date, such as <pubDate>.
         $date = date('m/d/Y', strtotime((string) $item->pubDate));

         $build[] = [
           '#markup' => '<p>' . $date . '<br><b><a href="' . $item->link . '">' . $item->title . '</a></b></p>',
         ];


        $count++;
      }
    }

    $build['#cache'] = [
      'max-age' => 24*0*60,
      'contexts' => ['url'], // Cache per URL (optional, if you want caching to be per URL)
    ];

    return $build;
  }
}
